@@ -29,7 +29,6 @@
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-from binascii import b2a_hex
 import unittest
 
 import pygit2
@@ -46,7 +45,7 @@ class BlobTest(utils.BareRepoTestCase):
     def test_read_blob(self):
         blob = self.repo[BLOB_SHA]
         self.assertEqual(blob.hex, BLOB_SHA)
-        sha = b2a_hex(blob.oid).decode('ascii')
+        sha = utils.oid_to_hex(blob.oid)
         self.assertEqual(sha, BLOB_SHA)
         self.assertTrue(isinstance(blob, pygit2.Blob))
         self.assertEqual(pygit2.GIT_OBJ_BLOB, blob.type)
